@@ -3,24 +3,12 @@
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
-# This file is part of UFL.
+# This file is part of UFL (https://www.fenicsproject.org)
 #
-# UFL is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# UFL is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with UFL. If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier:    LGPL-3.0-or-later
 
 
 from ufl.log import error
-from ufl.utils.str import as_native_strings
 from ufl.core.ufl_type import ufl_type
 from ufl.core.expr import Expr, ufl_err_str
 from ufl.core.operator import Operator
@@ -33,11 +21,9 @@ from ufl.constantvalue import Zero
 
 @ufl_type(num_ops=2)
 class IndexSum(Operator):
-    __slots__ = as_native_strings((
-        "_dimension",
-        "ufl_free_indices",
-        "ufl_index_dimensions",
-    ))
+    __slots__ = ("_dimension",
+                 "ufl_free_indices",
+                 "ufl_index_dimensions",)
 
     def __new__(cls, summand, index):
         # Error checks
